# ClearFileAssociationResponse

Describes the result of clearing a set of associations. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**deleted_associations** | [**[FileAssociation]**](FileAssociation.md) | The assocatiations which were deleted.  | 
**pending_delete_files** | [**[FileSummary]**](FileSummary.md) | The files which were marked as pending_delete in response to having all of their associations deleted.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


